==> v1.3.0.tar.gz: merlin-cryosparc/merlin6-short/cluster_script.sh <==
#!/usr/bin/env bash
# cryoSPARC cluster submission script template for SLURM
# Lane: merlin6-short v1.3.0 (2020-07-14)
#
# This is the 'short' configuration, intended for interactive jobs and rapid
# experimentation. Jobs are limited to 1 hour.
#
# If you edit this file, run 'cryosparcm cluster connect'

{# This template uses jinja2 syntax. #}
{%- macro _min(a, b) -%}
  {%- if a <= b %}{{a}}{% else %}{{b}}{% endif -%}
{%- endmacro -%}

# Available variables:
#  script_path_abs={{ script_path_abs }}
#      - the absolute path to the generated submission script
#  run_cmd={{ run_cmd }}
#      - the complete command-line string to run the job
#  num_cpu={{ num_cpu }}
#      - the number of CPUs needed
#  num_gpu={{ num_gpu }}
#      - the number of GPUs needed. Note: the code will use this many GPUs
#        starting from dev id 0. The cluster scheduler or this script have the
#        responsibility of setting CUDA_VISIBLE_DEVICES so that the job code
#        ends up using the correct cluster-allocated GPUs.
#  ram_gb={{ ram_gb }}
#      - the amount of RAM needed in GB
#  job_dir_abs={{ job_dir_abs }}
#      - absolute path to the job directory
#  project_dir_abs={{ project_dir_abs }}
#      - absolute path to the project dir
#  job_log_path_abs={{ job_log_path_abs }}
#      - absolute path to the log file for the job
#  worker_bin_path={{ worker_bin_path }}
#      - absolute path to the cryosparc worker command
#  run_args={{ run_args }}
#      - arguments to be passed to cryosparcw run
#  project_uid={{ project_uid }}
#      - uid of the project
#  job_uid={{ job_uid }}
#      - uid of the job
#  job_creator={{ job_creator }}
#      - name of the user that created the job (may contain spaces)
#  cryosparc_username={{ cryosparc_username }}
#      - cryosparc username of the user that created the job (usually an email)

#SBATCH --job-name=cryosparc_{{ project_uid }}_{{ job_uid }}
#SBATCH --output={{ job_log_path_abs }}.out
#SBATCH --error={{ job_log_path_abs }}.err
#SBATCH --ntasks=1
#SBATCH --threads-per-core=1
#SBATCH --mem-per-cpu={{ ((ram_gb*1000)/num_cpu)|int }}M

{%- if num_gpu == 0 %}
# Use CPU cluster
#SBATCH --partition=hourly
#SBATCH --time=1:00:00
#SBATCH --account=merlin
#SBATCH --cpus-per-task={{ num_cpu }}
{%- else %}
# Use GPU cluster
#SBATCH --partition=gpu-short,gpu
#SBATCH --time=1:00:00
#SBATCH --account=merlin-gpu
#SBATCH --gres=gpu:{{ _min(num_gpu, 2) }}
  {%- if num_gpu <= 2 %}
#SBATCH --cpus-per-task={{ _min(num_cpu, 8) }}
  {%- else %}
    {# Slurm requests too many CPU sometimes; restrict to 20 per machine #}
    {%- set num_nodes = (num_gpu/4) | round(0, 'ceil') | int %}
#SBATCH --cpus-per-task={{ _min(num_cpu, 20*num_nodes) }}
  {%- endif %}
{%- endif %}

# Print hostname, for debugging
hostname

# Make sure this matches the version of cuda used to compile cryosparc
module purge
module load cuda/10.0.130

srun {{ run_cmd }}

==> v1.5.0.tar.gz: merlin-cryosparc/merlin6-short/cluster_script.sh <==
#!/usr/bin/env bash
# cryoSPARC cluster submission script template for SLURM
# Lane: merlin6-short v1.5.0 (2021-05-28)
#
# This is the 'short' configuration, intended for interactive jobs and rapid
# experimentation. Jobs are limited to 1 hour.
#
# If you edit this file, run 'cryosparcm cluster connect'

{# This template uses jinja2 syntax. #}
{%- macro _min(a, b) -%}
  {%- if a <= b %}{{a}}{% else %}{{b}}{% endif -%}
{%- endmacro -%}

# Available variables:
#  script_path_abs={{ script_path_abs }}
#      - the absolute path to the generated submission script
#  run_cmd={{ run_cmd }}
#      - the complete command-line string to run the job
#  num_cpu={{ num_cpu }}
#      - the number of CPUs needed
#  num_gpu={{ num_gpu }}
#      - the number of GPUs needed. Note: the code will use this many GPUs
#        starting from dev id 0. The cluster scheduler or this script have the
#        responsibility of setting CUDA_VISIBLE_DEVICES so that the job code
#        ends up using the correct cluster-allocated GPUs.
#  ram_gb={{ ram_gb }}
#      - the amount of RAM needed in GB
#  job_dir_abs={{ job_dir_abs }}
#      - absolute path to the job directory
#  project_dir_abs={{ project_dir_abs }}
#      - absolute path to the project dir
#  job_log_path_abs={{ job_log_path_abs }}
#      - absolute path to the log file for the job
#  worker_bin_path={{ worker_bin_path }}
#      - absolute path to the cryosparc worker command
#  run_args={{ run_args }}
#      - arguments to be passed to cryosparcw run
#  project_uid={{ project_uid }}
#      - uid of the project
#  job_uid={{ job_uid }}
#      - uid of the job
#  job_creator={{ job_creator }}
#      - name of the user that created the job (may contain spaces)
#  cryosparc_username={{ cryosparc_username }}
#      - cryosparc username of the user that created the job (usually an email)

#SBATCH --job-name=cryosparc_{{ project_uid }}_{{ job_uid }}
#SBATCH --output={{ job_log_path_abs }}.out
#SBATCH --error={{ job_log_path_abs }}.err
#SBATCH --ntasks=1
#SBATCH --threads-per-core=1
#SBATCH --mem-per-cpu={{ ((ram_gb*1000)/num_cpu)|int }}M

{%- if num_gpu == 0 %}
# Use CPU cluster
#SBATCH --partition=hourly
#SBATCH --time=1:00:00
#SBATCH --cpus-per-task={{ num_cpu }}
{%- else %}
# Use GPU cluster
#SBATCH --partition=gpu-short
#SBATCH --cluster=gmerlin6
#SBATCH --time=2:00:00
#SBATCH --gpus={{ num_gpu }}
  {%- if num_gpu <= 2 %}
#SBATCH --cpus-per-task={{ _min(num_cpu, 8) }}
  {%- else %}
    {# Slurm requests too many CPU sometimes; restrict to 20 per machine #}
    {%- set num_nodes = (num_gpu/4) | round(0, 'ceil') | int %}
#SBATCH --cpus-per-task={{ _min(num_cpu, 20*num_nodes) }}
  {%- endif %}
{%- endif %}

# Print hostname, for debugging
echo "Job Id: $SLURM_JOBID"
echo "Host:   $SLURM_NODELIST"

# Make sure this matches the version of cuda used to compile cryosparc
module purge
module load cuda/10.0.130

srun {{ run_cmd }}

EXIT_CODE=$?
echo "Exit code: $EXIT_CODE"
exit $?
